@@ -7,7 +7,7 @@ no warnings qw(uninitialized);
 use Carp;
 use File::Spec;
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 $VERSION = eval $VERSION;
 
 sub import {
@@ -24,7 +24,7 @@ sub unimport {
     for my $args (@_) {
         if (ref($args)) {
             $package->_check_import_argument($args);
-            $package->_thwart_module(%$args);
+            $package->_thwart_modules(%$args);
         } else {
             disable_warning_category($args);
         }
@@ -41,6 +41,11 @@ sub _check_import_argument {
     if (!exists $argument->{warning} || !exists $argument->{thwart_module}) {
         croak "Argument keys must include warning and thwart_module";
     }
+    if (   ref($argument->{thwart_module})
+        && ref($argument->{thwart_module}) ne 'ARRAY')
+    {
+        croak "Argument thwart_module should be a scalar or an arrayref";
+    }
     _check_warning_category($argument->{warning}) or die;
 }
 
@@ -50,7 +55,7 @@ warnings::everywhere - a way of ensuring consistent global warning settings
 
 =head1 VERSION
 
-This is version 0.020.
+This is version 0.021.
 
 =head1 SYNOPSIS
 
@@ -412,7 +417,21 @@ sub _check_warning_category {
     return 1;
 }
 
-sub _thwart_module {
+sub _thwart_modules {
+    my ($package, %args) = @_;
+
+    my @modules
+        = ref($args{thwart_module}) eq 'ARRAY'
+        ? @{ $args{thwart_module} }
+        : $args{thwart_module};
+
+
+    for my $module (@modules) {
+        $package->_thwart_this_module(%args, thwart_module => $module);
+    }
+}
+
+sub _thwart_this_module {
     my ($package, %args) = @_;
 
     # There are two ways of thwarting modules: the usual Perlish way,
@@ -462,12 +481,14 @@ sub _thwart_module {
         if ($mode eq 'append_sub') {
             my $extra_code = <<EXTRACODE;
 $injection_warning_start
-my \$__warnings_everywhere_orig_import = \\\&${module}::import;
-{
-    no warnings 'redefine';
-    *${module}::import = sub {
-        \$__warnings_everywhere_orig_import->(\@_);
-        $source_code_unimport
+if (!\$warnings::everywhere::_thwarted_module{"${module}"}++) {
+    my \$__warnings_everywhere_orig_import = \\\&${module}::import;
+    {
+        no warnings 'redefine';
+        *${module}::import = sub {
+            \$__warnings_everywhere_orig_import->(\@_);
+            $source_code_unimport
+        };
     }
 }
 $injection_warning_end
